@@ -4,19 +4,22 @@
 .. _tight_layout_guide:
 
 ==================
-Tight Layout guide
+Tight layout guide
 ==================
 
 How to use tight-layout to fit plots within your figure cleanly.
 
+.. tip::
+
+   *tight_layout* was the first layout engine in Matplotlib. The more modern
+   and more capable :ref:`Constrained Layout <constrainedlayout_guide>` should
+   typically be used instead.
+
 *tight_layout* automatically adjusts subplot params so that the
 subplot(s) fits in to the figure area. This is an experimental
 feature and may not work for some cases. It only checks the extents
 of ticklabels, axis labels, and titles.
 
-An alternative to *tight_layout* is :ref:`constrained_layout
-<constrainedlayout_guide>`.
-
 Simple example
 ==============
 
@@ -45,7 +48,7 @@ fig, ax = plt.subplots()
 example_plot(ax, fontsize=24)
 
 # %%
-# To prevent this, the location of axes needs to be adjusted. For
+# To prevent this, the location of Axes needs to be adjusted. For
 # subplots, this can be done manually by adjusting the subplot parameters
 # using `.Figure.subplots_adjust`. `.Figure.tight_layout` does this
 # automatically.
@@ -61,7 +64,7 @@ plt.tight_layout()
 # equivalently, set :rc:`figure.autolayout` to ``True``.
 #
 # When you have multiple subplots, often you see labels of different
-# axes overlapping each other.
+# Axes overlapping each other.
 
 plt.close('all')
 
@@ -136,7 +139,7 @@ plt.tight_layout()
 
 # %%
 # Although not thoroughly tested, it seems to work for subplots with
-# aspect != "auto" (e.g., axes with images).
+# aspect != "auto" (e.g., Axes with images).
 
 arr = np.arange(100).reshape((10, 10))
 
@@ -152,18 +155,22 @@ plt.tight_layout()
 # Caveats
 # =======
 #
-# * `~matplotlib.pyplot.tight_layout` considers all artists on the axes by
+# * `~matplotlib.pyplot.tight_layout` considers all artists on the Axes by
 #   default.  To remove an artist from the layout calculation you can call
 #   `.Artist.set_in_layout`.
 #
 # * ``tight_layout`` assumes that the extra space needed for artists is
-#   independent of the original location of axes. This is often true, but there
+#   independent of the original location of Axes. This is often true, but there
 #   are rare cases where it is not.
 #
 # * ``pad=0`` can clip some texts by a few pixels. This may be a bug or
 #   a limitation of the current algorithm, and it is not clear why it
 #   happens. Meanwhile, use of pad larger than 0.3 is recommended.
 #
+# * The algorithm of ``tight_layout`` does not necessarily converge,
+#   i.e. calling ``tight_layout`` multiple times can lead to slight
+#   variations in the layout between the calls.
+#
 # Use with GridSpec
 # =================
 #
@@ -209,13 +216,13 @@ gs1.tight_layout(fig, rect=[0, 0, 0.5, 1.0])
 
 
 # %%
-# Legends and Annotations
+# Legends and annotations
 # =======================
 #
 # Pre Matplotlib 2.2, legends and annotations were excluded from the bounding
 # box calculations that decide the layout.  Subsequently, these artists were
 # added to the calculation, but sometimes it is undesirable to include them.
-# For instance in this case it might be good to have the axes shrink a bit
+# For instance in this case it might be good to have the Axes shrink a bit
 # to make room for the legend:
 
 fig, ax = plt.subplots(figsize=(4, 3))
@@ -262,7 +269,7 @@ plt.tight_layout()
 # ========
 #
 # If you create a colorbar with `.Figure.colorbar`, the created colorbar is
-# drawn in a Subplot as long as the parent axes is also a Subplot, so
+# drawn in a Subplot as long as the parent Axes is also a Subplot, so
 # `.Figure.tight_layout` will work.
 
 plt.close('all')
