@@ -1,16 +1,17 @@
 import builtins
 import os
-import subprocess
 import sys
 import textwrap
 
+from matplotlib.testing import subprocess_run_for_testing
+
 
 def test_simple():
     assert 1 + 1 == 2
 
 
 def test_override_builtins():
-    import pylab  # type: ignore
+    import pylab  # type: ignore[import]
     ok_to_override = {
         '__name__',
         '__doc__',
@@ -41,6 +42,7 @@ def test_lazy_imports():
     assert 'urllib.request' not in sys.modules
     """)
 
-    subprocess.check_call(
+    subprocess_run_for_testing(
         [sys.executable, '-c', source],
-        env={**os.environ, "MPLBACKEND": "", "MATPLOTLIBRC": os.devnull})
+        env={**os.environ, "MPLBACKEND": "", "MATPLOTLIBRC": os.devnull},
+        check=True)
